@@ -24,7 +24,7 @@ attribute table. For example:
    'geometry': {'type': 'Point', 'coordinates': (0.0, 0.0)},
    'properties': {'label': u'Null Island'} }
 
-is a Fiona feature with a point geometry and one property. 
+is a Fiona feature with a point geometry and one property.
 
 Features are read and written using objects returned by the
 ``collection`` function. These ``Collection`` objects are a lot like
@@ -46,8 +46,8 @@ feature writing to a "points.shp" file.
   ...     output_schema['geometry'] = 'Point'
   ...     with collection(
   ...             "points.shp", "w",
-  ...             crs=inp.crs, 
-  ...             driver="ESRI Shapefile", 
+  ...             crs=inp.crs,
+  ...             driver="ESRI Shapefile",
   ...             schema=output_schema
   ...             ) as out:
   ...         for f in inp.filter(
@@ -62,28 +62,29 @@ Because Fiona collections are context managers, they are closed and (in
 writing modes) flush contents to disk when their ``with`` blocks end.
 """
 
-__all__ = ['bounds', 'listlayers', 'open', 'prop_type', 'prop_width']
-__version__ = "1.6.2"
-
 import logging
 import os
 from six import string_types
 
 from fiona.collection import Collection, BytesCollection, vsi_path
-from fiona._drivers import driver_count, GDALEnv, supported_drivers
-from fiona.odict import OrderedDict
-from fiona.ogrext import _bounds, _listlayers, FIELD_TYPES_MAP
+from fiona._drivers import driver_count, GDALEnv
+from fiona.drvsupport import supported_drivers
+from fiona.compat import OrderedDict
+from fiona.ogrext import _bounds, _listlayers, FIELD_TYPES_MAP, _remove
+from fiona.ogrext import (
+    calc_gdal_version_num, get_gdal_version_num, get_gdal_release_name)
 
 # These modules are imported by fiona.ogrext, but are also import here to
 # help tools like cx_Freeze find them automatically
 from fiona import _geometry, _err, rfc3339
 import uuid
 
-log = logging.getLogger('Fiona')
-class NullHandler(logging.Handler):
-    def emit(self, record):
-        pass
-log.addHandler(NullHandler())
+
+__all__ = ['bounds', 'listlayers', 'open', 'prop_type', 'prop_width']
+__version__ = "1.7.10.post1"
+__gdal_version__ = get_gdal_release_name().decode('utf-8')
+
+log = logging.getLogger(__name__)
 
 
 def open(
@@ -97,27 +98,26 @@ def open(
         vfs=None,
         enabled_drivers=None,
         crs_wkt=None):
-    
     """Open file at ``path`` in ``mode`` "r" (read), "a" (append), or
     "w" (write) and return a ``Collection`` object.
-    
+
     In write mode, a driver name such as "ESRI Shapefile" or "GPX" (see
     OGR docs or ``ogr2ogr --help`` on the command line) and a schema
     mapping such as:
-    
+
       {'geometry': 'Point',
-       'properties': [('class', 'int'), ('label', 'str'), 
+       'properties': [('class', 'int'), ('label', 'str'),
                       ('value', 'float')]}
-    
+
     must be provided. If a particular ordering of properties ("fields"
     in GIS parlance) in the written file is desired, a list of (key,
     value) pairs as above or an ordered dict is required. If no ordering
     is needed, a standard dict will suffice.
-    
+
     A coordinate reference system for collections in write mode can be
     defined by the ``crs`` parameter. It takes Proj4 style mappings like
-    
-      {'proj': 'longlat', 'ellps': 'WGS84', 'datum': 'WGS84', 
+
+      {'proj': 'longlat', 'ellps': 'WGS84', 'datum': 'WGS84',
        'no_defs': True}
 
     short hand strings like
@@ -129,10 +129,10 @@ def open(
     The drivers used by Fiona will try to detect the encoding of data
     files. If they fail, you may provide the proper ``encoding``, such
     as 'Windows-1252' for the Natural Earth datasets.
-    
+
     When the provided path is to a file containing multiple named layers
     of data, a layer can be singled out by ``layer``.
-    
+
     A virtual filesystem can be specified. The ``vfs`` parameter may be
     an Apache Commons VFS style string beginning with "zip://" or
     "tar://"". In this case, the ``path`` must be an absolute path
@@ -160,9 +160,9 @@ def open(
                 raise IOError("no such archive file: %r" % archive)
         elif path != '-' and not os.path.exists(path):
             raise IOError("no such file or directory: %r" % path)
-        c = Collection(path, mode, driver=driver,
-                encoding=encoding, layer=layer, vsi=vsi, archive=archive,
-                enabled_drivers=enabled_drivers)
+        c = Collection(path, mode, driver=driver, encoding=encoding,
+                       layer=layer, vsi=vsi, archive=archive,
+                       enabled_drivers=enabled_drivers)
     elif mode == 'w':
         if schema:
             # Make an ordered dict of schema properties.
@@ -170,10 +170,9 @@ def open(
             this_schema['properties'] = OrderedDict(schema['properties'])
         else:
             this_schema = None
-        c = Collection(path, mode,
-                crs=crs, driver=driver, schema=this_schema,
-                encoding=encoding, layer=layer, vsi=vsi, archive=archive,
-                enabled_drivers=enabled_drivers, crs_wkt=crs_wkt)
+        c = Collection(path, mode, crs=crs, driver=driver, schema=this_schema,
+                       encoding=encoding, layer=layer, vsi=vsi, archive=archive,
+                       enabled_drivers=enabled_drivers, crs_wkt=crs_wkt)
     else:
         raise ValueError(
             "mode string must be one of 'r', 'w', or 'a', not %s" % mode)
@@ -182,12 +181,39 @@ def open(
 collection = open
 
 
+def remove(path_or_collection, driver=None):
+    """Deletes an OGR data source
+
+    The required ``path`` argument may be an absolute or relative file path.
+    Alternatively, a Collection can be passed instead in which case the path
+    and driver are automatically determined. Otherwise the ``driver`` argument
+    must be specified.
+
+    Raises a ``RuntimeError`` if the data source cannot be deleted.
+
+    Example usage:
+
+      fiona.remove('test.shp', 'ESRI Shapefile')
+
+    """
+    if isinstance(path_or_collection, Collection):
+        collection = path_or_collection
+        path = collection.path
+        driver = collection.driver
+        collection.close()
+    else:
+        path = path_or_collection
+        if driver is None:
+            raise ValueError("The driver argument is required when removing a path")
+    _remove(path, driver)
+
+
 def listlayers(path, vfs=None):
     """Returns a list of layer names in their index order.
-    
+
     The required ``path`` argument may be an absolute or relative file or
     directory path.
-    
+
     A virtual filesystem can be specified. The ``vfs`` parameter may be
     an Apache Commons VFS style string beginning with "zip://" or
     "tar://"". In this case, the ``path`` must be an absolute path within
@@ -197,18 +223,19 @@ def listlayers(path, vfs=None):
         raise TypeError("invalid path: %r" % path)
     if vfs and not isinstance(vfs, string_types):
         raise TypeError("invalid vfs: %r" % vfs)
-    
+
     path, vsi, archive = parse_paths(path, vfs)
-    
+
     if archive:
         if not os.path.exists(archive):
             raise IOError("no such archive file: %r" % archive)
     elif not os.path.exists(path):
         raise IOError("no such file or directory: %r" % path)
-    
+
     with drivers():
         return _listlayers(vsi_path(path, vsi, archive))
 
+
 def parse_paths(path, vfs=None):
     archive = vsi = None
     if vfs:
@@ -221,6 +248,7 @@ def parse_paths(path, vfs=None):
         vsi = parts.pop() if parts else None
     return path, vsi, archive
 
+
 def prop_width(val):
     """Returns the width of a str type property.
 
@@ -235,11 +263,12 @@ def prop_width(val):
         return int((val.split(":")[1:] or ["80"])[0])
     return None
 
+
 def prop_type(text):
     """Returns a schema property's proper Python type.
-    
+
     Example:
-    
+
       >>> prop_type('int')
       <class 'int'>
       >>> prop_type('str:25')
@@ -261,7 +290,7 @@ def drivers(*args, **kwargs):
 
 def bounds(ob):
     """Returns a (minx, miny, maxx, maxy) bounding box.
-    
+
     The ``ob`` may be a feature record or geometry."""
     geom = ob.get('geometry') or ob
     return _bounds(geom)
